##
##  op.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         op
Summary:      Controlled Operator Privilege Escalation
URL:          https://github.com/dagwieers/op
Vendor:       T. Christiansen, D. Koblas, H. Owen, A. Thomas.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        ShellUtils
License:      MIT-style
Version:      1.34
Release:      20190126

#   list of sources
Source0:      https://github.com/dagwieers/op/archive/%{version}.tar.gz
Source1:      op.conf
Patch0:       op.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    The op(1) tool provides a flexible means for system administrators
    to grant access to certain root operations without having to give
    them full superuser privileges. Different sets of users may access
    different operations, and the security-related aspects of each
    operation can be carefully controlled.

%track
    prog op = {
        version   = %{version}
        url       = https://github.com/dagwieers/op/releases
        regex     = (__VER__)\.tar\.gz
    }

%prep
    #   unpack distribution
    %setup -q
    %patch -p0

    #   fix paths on man page
    %{l_shtool} subst \
        -e 's;/etc/op.conf;%{l_prefix}/etc/op/op.conf;g' \
        -e 's;/etc/op.d;%{l_prefix}/etc/op/op.d;g' \
        op.1

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --sysconfdir=%{l_prefix}/etc/op

    #   build package
    %{l_make} %{l_mflags -O}

%install

    #   install package
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   install default configuration with examples
    l_su="`%{l_shtool} path su`"
    l_id="`%{l_shtool} path id`"
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/op/op.d
    %{l_shtool} install -c -m 644 \
        -e "s;@l_su@;$l_su;g" \
        -e "s;@l_id@;$l_id;g" \
        %{SOURCE op.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/op/

    #   strip installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(4111,%{l_susr},%{l_sgrp})         %{l_prefix}/bin/op' \
        '%dir    %attr(0700,%{l_susr},%{l_sgrp}) %{l_prefix}/etc/op' \
        '%dir    %attr(0700,%{l_susr},%{l_sgrp}) %{l_prefix}/etc/op/op.d' \
        '%config %attr(0600,%{l_susr},%{l_sgrp}) %{l_prefix}/etc/op/op.conf'

%files -f files

%clean

